@@ -164,11 +164,15 @@ class GitClient(VcsClientBase):
 
     def checkout(self, url, refname=None, verbose=False, shallow=False):
         """calls git clone and then, if refname was given, update(refname)"""
+        if url is None or url.strip() == '':
+            raise ValueError('Invalid empty url : "%s"' % url)
 
         #since we cannot know whether refname names a branch, clone master initially
         cmd = 'git clone'
         if shallow:
             cmd += ' --depth 1'
+            if LooseVersion(self.gitversion) >= LooseVersion('1.7.10'):
+                cmd += ' --no-single-branch'
         cmd += ' --recursive %s %s' % (url, self._path)
         value, _, _ = run_shell_command(cmd,
                                         shell=True,
