@@ -143,6 +143,8 @@ class HgClient(VcsClientBase):
                 os.path.isdir(os.path.join(self._path, '.hg')))
 
     def checkout(self, url, version='', verbose=False, shallow=False):
+        if url is None or url.strip() == '':
+            raise ValueError('Invalid empty url : "%s"' % url)
         if self.path_exists():
             sys.stderr.write("Error: cannot checkout into existing directory\n")
             return False
