@@ -103,6 +103,8 @@ class SvnClient(VcsClientBase):
                os.path.isdir(os.path.join(self._path, '.svn'))
 
     def checkout(self, url, version='', verbose=False, shallow=False):
+        if url is None or url.strip() == '':
+            raise ValueError('Invalid empty url : "%s"' % url)
         # Need to check as SVN does not care
         if self.path_exists():
             sys.stderr.write("Error: cannot checkout into existing "
